/*
   SPDX-FileCopyrightText: 2016-2026 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "viewerpluginexternalscripttest.h"

ViewerPluginExternalscriptTest::ViewerPluginExternalscriptTest(QObject *parent)
    : QObject(parent)
{
}

ViewerPluginExternalscriptTest::~ViewerPluginExternalscriptTest()
{
}

QTEST_MAIN(ViewerPluginExternalscriptTest)

#include "moc_viewerpluginexternalscripttest.cpp"
