/*
   SPDX-FileCopyrightText: 2015-2026 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "grantleeheaderstrategy.h"

using namespace MessageViewer;

GrantleeHeaderStrategy::GrantleeHeaderStrategy() = default;

GrantleeHeaderStrategy::~GrantleeHeaderStrategy() = default;
