/*
  SPDX-FileCopyrightText: 2021-2026 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-only
*/

#include "mailmergemenu.h"

MailMergeMenu::MailMergeMenu(QWidget *parent)
    : QMenu(parent)
{
}

MailMergeMenu::~MailMergeMenu() = default;

#include "moc_mailmergemenu.cpp"
