/*
   SPDX-FileCopyrightText: 2019-2026 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include <QObject>

class DKIMGeneralWidgetTest : public QObject
{
    Q_OBJECT
public:
    explicit DKIMGeneralWidgetTest(QObject *parent = nullptr);
    ~DKIMGeneralWidgetTest() override = default;
private Q_SLOTS:
    void shouldHaveDefaultValues();
};
