/*
   SPDX-FileCopyrightText: 2018-2026 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "gravatarconfiguresettingsplugindialogtest.h"
#include <QTest>

QTEST_MAIN(GravatarConfigureSettingsPluginDialogTest)

GravatarConfigureSettingsPluginDialogTest::GravatarConfigureSettingsPluginDialogTest(QObject *parent)
    : QObject(parent)
{
}

#include "moc_gravatarconfiguresettingsplugindialogtest.cpp"
